@@ -2,7 +2,7 @@
 #
 #       Installation of the include files in the OS/400 library.
 #
-# $Id: make-include.sh,v 1.4 2008-12-11 19:20:03 patrickm Exp $
+# $Id: make-include.sh,v 1.6 2009-10-23 15:05:45 patrickm Exp $
 
 SCRIPTDIR=`dirname "${0}"`
 . "${SCRIPTDIR}/initscript.sh"
@@ -35,15 +35,25 @@ fi
 copy_hfile()
 
 {
+	destfile="${1}"
+	srcfile="${2}"
+	shift
+	shift
         sed -e '1i\
 #pragma enum(int)\
-' -e '$a\
+' "${@}" -e '$a\
 #pragma enum(pop)\
-' < "${2}" > "${1}"
+' < "${srcfile}" > "${destfile}"
 }
 
 #       Copy the header files.
 
+DEST="${SRCPF}/`db2_name curl/curl.h`.MBR"
+if action_needed "${DEST}" curl/curl.h
+then	copy_hfile "${DEST}" curl/curl.h -e                             \
+            's/^# *include  *[<"]curl\/curlbuild.h[">]/#include "curlbuild.h"/'
+fi
+
 for HFILE in curl/*.h ${SCRIPTDIR}/ccsidcurl.h
 do      DEST="${SRCPF}/`db2_name \"${HFILE}\"`.MBR"
         if action_needed "${DEST}" "${HFILE}"
@@ -55,3 +65,15 @@ done
 #       Copy the ILE/RPG include file, setting-up version number.
 
         versioned_copy "${SCRIPTDIR}/curl.inc.in" "${SRCPF}/CURL.INC.MBR"
+
+
+#	Duplicate file H as CURL to support more include path forms.
+
+if action_needed "${LIBIFSNAME}/CURL.FILE"
+then	:
+else	system "DLTF FILE(${TARGETLIB}/CURL)"
+fi
+
+CMD="CRTDUPOBJ OBJ(H) FROMLIB(${TARGETLIB}) OBJTYPE(*FILE) TOLIB(*FROMLIB)"
+CMD="${CMD} NEWOBJ(CURL) DATA(*YES)"
+system "${CMD}"
