@@ -5,7 +5,7 @@
  *                            | (__| |_| |  _ <| |___
  *                             \___|\___/|_| \_\_____|
  *
- * $Id: lib506.c,v 1.14 2007-02-04 12:12:02 giva Exp $
+ * $Id: lib506.c,v 1.23 2009-05-08 02:14:50 yangtse Exp $
  */
 
 #include "test.h"
@@ -13,19 +13,14 @@
 #include <ctype.h>
 #include <errno.h>
 
-#include <mprintf.h>
+#include <curl/mprintf.h>
 
-const char *HOSTHEADER = "Host: www.host.foo.com";
-const char *JAR = "log/jar506";
+#include "memdebug.h"
+
+static const char *HOSTHEADER = "Host: www.host.foo.com";
+static const char *JAR = "log/jar506";
 #define THREADS 2
 
-void lock(CURL *handle, curl_lock_data data, curl_lock_access access,
-          void *useptr );
-void unlock(CURL *handle, curl_lock_data data, void *useptr );
-struct curl_slist *sethost(struct curl_slist *headers);
-void *fire(void *ptr);
-char *suburl(const char *base, int i);
-
 /* struct containing data of a thread */
 struct Tdata {
   CURLSH *share;
@@ -38,14 +33,14 @@ struct userdata {
 };
 
 /* lock callback */
-void lock(CURL *handle, curl_lock_data data, curl_lock_access access,
+static void my_lock(CURL *handle, curl_lock_data data, curl_lock_access laccess,
           void *useptr )
 {
   const char *what;
   struct userdata *user = (struct userdata *)useptr;
 
   (void)handle;
-  (void)access;
+  (void)laccess;
 
   switch ( data ) {
     case CURL_LOCK_DATA_SHARE:
@@ -61,12 +56,12 @@ void lock(CURL *handle, curl_lock_data data, curl_lock_access access,
       fprintf(stderr, "lock: no such data: %d\n", (int)data);
       return;
   }
-  printf("lock:   %-6s <%s>: %d\n", what, user->text, user->counter);
+  printf("lock:   %-6s [%s]: %d\n", what, user->text, user->counter);
   user->counter++;
 }
 
 /* unlock callback */
-void unlock(CURL *handle, curl_lock_data data, void *useptr )
+static void my_unlock(CURL *handle, curl_lock_data data, void *useptr )
 {
   const char *what;
   struct userdata *user = (struct userdata *)useptr;
@@ -85,13 +80,13 @@ void unlock(CURL *handle, curl_lock_data data, void *useptr )
       fprintf(stderr, "unlock: no such data: %d\n", (int)data);
       return;
   }
-  printf("unlock: %-6s <%s>: %d\n", what, user->text, user->counter);
+  printf("unlock: %-6s [%s]: %d\n", what, user->text, user->counter);
   user->counter++;
 }
 
 
 /* build host entry */
-struct curl_slist *sethost(struct curl_slist *headers)
+static struct curl_slist *sethost(struct curl_slist *headers)
 {
   (void)headers;
   return curl_slist_append(NULL, HOSTHEADER );
@@ -99,7 +94,7 @@ struct curl_slist *sethost(struct curl_slist *headers)
 
 
 /* the dummy thread function */
-void *fire(void *ptr)
+static void *fire(void *ptr)
 {
   CURLcode code;
   struct curl_slist *headers;
@@ -113,11 +108,11 @@ void *fire(void *ptr)
   }
 
   headers = sethost(NULL);
-  curl_easy_setopt(curl, CURLOPT_VERBOSE,    1);
-  curl_easy_setopt(curl, CURLOPT_HTTPHEADER, (void*)headers);
-  curl_easy_setopt(curl, CURLOPT_URL,        (void*)tdata->url);
+  curl_easy_setopt(curl, CURLOPT_VERBOSE,    1L);
+  curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headers);
+  curl_easy_setopt(curl, CURLOPT_URL,        tdata->url);
   printf( "CURLOPT_SHARE\n" );
-  curl_easy_setopt(curl, CURLOPT_SHARE, (void*)tdata->share);
+  curl_easy_setopt(curl, CURLOPT_SHARE, tdata->share);
 
   printf( "PERFORM\n" );
   code = curl_easy_perform(curl);
@@ -135,9 +130,9 @@ void *fire(void *ptr)
 
 
 /* build request url */
-char *suburl(const char *base, int i)
+static char *suburl(const char *base, int i)
 {
-  return curl_maprintf("%s000%c", base, 48+i);
+  return curl_maprintf("%s%.4d", base, i);
 }
 
 
@@ -173,11 +168,11 @@ int test(char *URL)
 
   if ( CURLSHE_OK == scode ) {
     printf( "CURLSHOPT_LOCKFUNC\n" );
-    scode = curl_share_setopt( share, CURLSHOPT_LOCKFUNC, lock);
+    scode = curl_share_setopt( share, CURLSHOPT_LOCKFUNC, my_lock);
   }
   if ( CURLSHE_OK == scode ) {
     printf( "CURLSHOPT_UNLOCKFUNC\n" );
-    scode = curl_share_setopt( share, CURLSHOPT_UNLOCKFUNC, unlock);
+    scode = curl_share_setopt( share, CURLSHOPT_UNLOCKFUNC, my_unlock);
   }
   if ( CURLSHE_OK == scode ) {
     printf( "CURLSHOPT_USERDATA\n" );
@@ -229,7 +224,7 @@ int test(char *URL)
 
   url = suburl( URL, i );
   headers = sethost( NULL );
-  curl_easy_setopt( curl, CURLOPT_HTTPHEADER, (void*)headers );
+  curl_easy_setopt( curl, CURLOPT_HTTPHEADER, headers );
   curl_easy_setopt( curl, CURLOPT_URL,        url );
   printf( "CURLOPT_SHARE\n" );
   curl_easy_setopt( curl, CURLOPT_SHARE,      share );
