@@ -5,11 +5,13 @@
  *                            | (__| |_| |  _ <| |___
  *                             \___|\___/|_| \_\_____|
  *
- * $Id: lib515.c,v 1.3 2006-10-25 09:20:44 yangtse Exp $
+ * $Id: lib515.c,v 1.5 2008-09-20 04:26:57 yangtse Exp $
  */
 
 #include "test.h"
 
+#include "memdebug.h"
+
 int test(char *URL)
 {
   CURL *curl;
@@ -29,9 +31,9 @@ int test(char *URL)
   /* First set the URL that is about to receive our POST. */
   curl_easy_setopt(curl, CURLOPT_URL, URL);
   curl_easy_setopt(curl, CURLOPT_POSTFIELDS, NULL);
-  curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, 0);
-  curl_easy_setopt(curl, CURLOPT_VERBOSE, 1); /* show verbose for debug */
-  curl_easy_setopt(curl, CURLOPT_HEADER, 1); /* include header */
+  curl_easy_setopt(curl, CURLOPT_POSTFIELDSIZE, 0L);
+  curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L); /* show verbose for debug */
+  curl_easy_setopt(curl, CURLOPT_HEADER, 1L); /* include header */
 
   /* Now, we should be making a zero byte POST request */
   res = curl_easy_perform(curl);
